MAFIAT
======

The Magnetic Field Analysis Tools (MAFIAT) package facilitates the investigation of the magnetic twist of flux ropes in coronal simulation domains.

Installation
------------
Mafiat requires python >= 3.9.

It can be installed from `PyPI <https://pypi.org/project/mafiat/>`_ using:

.. code:: bash

    pip install mafiat
